﻿using System;
using System.Reflection;

namespace RHPluginWithEndpoint
{/// <summary>
 /// EndPoints class.
 /// in the plugin.cs, add the following override to OnLoad()
 ///         protected override LoadReturnCode OnLoad(ref string errorMessage)
 ///         {
 ///         Rhino.Runtime.HostUtils.RegisterComputeEndpoint(EndPoints._endPointRoot, typeof(EndPoints));
 ///         return base.OnLoad(ref errorMessage);
 ///         }
 /// </summary>
    public static class EndPoints
    {
        /// <summary>
        /// Major Version helper.
        /// </summary>
        private static string _majorVersion = Assembly.GetExecutingAssembly()
            .GetName().Version
            .ToString()
            .Split('.')[0]; // Major version
        /// <summary>
        /// Root of this Endpoint class `Api.Solver.v#`
        /// </summary>
        public static string _endPointRoot = string.Format("Api.Solver.v{0}", _majorVersion);
        /// <summary>
        /// Sample Endpoint. About plugin.
        /// </summary>
        /// <returns></returns>
        public static string About()
        {
            var msg = $"Rhino Plugin with Computer Endpoints have been installed on {Environment.MachineName}";
            return msg;
        }

        /// <summary>
        /// Get Rhino Compute Host name. Sleep for 1 second for load balance test.
        /// </summary>
        /// <returns></returns>
        public static string GetHostname()
        {
            System.Threading.Thread.Sleep(1000);
            return Environment.MachineName;
        }
        /// <summary>
        /// Sample endpoint. Save export glb file
        /// </summary>
        /// <returns></returns>
        public static string CreateGLTF()
        {
            using (var doc = Rhino.RhinoDoc.CreateHeadless(null))
            {
                var sphere = new Rhino.Geometry.Sphere(Rhino.Geometry.Plane.WorldXY, 250.0);


                doc.Objects.AddSphere(sphere);
                //var rc = doc.SaveAs("c:\\app\\fileSaved.3dm");
                var rc = doc.Export("c:\\app\\fileExported.glb");
                var message = string.Format("Completed {0}", rc);
                return message;
            }
        }

    }
}
