﻿using Rhino.PlugIns;

namespace RHPluginWithEndpoint
{
    ///<summary>
    /// <para>Every RhinoCommon .rhp assembly must have one and only one PlugIn-derived
    /// class. DO NOT create instances of this class yourself. It is the
    /// responsibility of Rhino to create an instance of this class.</para>
    /// <para>To complete plug-in information, please also see all PlugInDescription
    /// attributes in AssemblyInfo.cs (you might need to click "Project" ->
    /// "Show All Files" to see it in the "Solution Explorer" window).</para>
    ///</summary>
    public class RHPlugin : Rhino.PlugIns.PlugIn

    {
        public RHPlugin()
        {
            Instance = this;
        }

        ///<summary>Gets the only instance of the RHPlugin plug-in.</summary>
        public static RHPlugin Instance
        {
            get; private set;
        }

        // You can override methods here to change the plug-in behavior on
        // loading and shut down, add options pages to the Rhino _Option command
        // and maintain plug-in wide options in a document.
        /// <summary>
        /// Load Enpoints on a Compute Server.
        /// </summary>
        /// <param name="errorMessage"></param>
        /// <returns></returns>
        protected override LoadReturnCode OnLoad(ref string errorMessage)
        {
            // For every endpoint class, set the endpoint root and add like so.
            Rhino.Runtime.HostUtils.RegisterComputeEndpoint(EndPoints._endPointRoot, typeof(EndPoints));
            return base.OnLoad(ref errorMessage);
        }
        /// <summary>
        /// Load at Startup
        /// </summary>
        public override PlugInLoadTime LoadTime => PlugInLoadTime.AtStartup;
    }
}